package com.cultural.heritage.controller.operategood;


import com.cultural.heritage.annotation.AuthCheck;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.constant.UserConstant;
import com.cultural.heritage.controller.userinfo.UserController;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.model.dto.good.GoodAddRequest;
import com.cultural.heritage.model.entity.Good;
import com.cultural.heritage.service.operategood.GoodService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.xml.transform.Result;


/**
 * 商品接口
 */
@RestController
@RequestMapping("/goods")
@Slf4j
@Tag(name = "商品接口")
public class GoodController {

    @Resource
    private GoodService goodService;


    /**
     * 添加商品
     * @param goodAddRequest  商品添加请求体
     * @return
     */
    @PostMapping("/add")
//    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Good> addGood(@RequestBody GoodAddRequest goodAddRequest) {
        if (goodAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Good good = new Good();
        BeanUtils.copyProperties(goodAddRequest, good);
        good.setIsGoodType(1);
        boolean save = goodService.save(good);
        if (!save) {
            throw new BusinessException(ErrorCode.SYSTEM_ERROR);
        }
        return ResultUtils.success(good, "商品插入成功");
    }



}
